@@ -127,6 +127,7 @@ void MainWindow::get_roms()
 
 void MainWindow::rom_exec_savestate()
 {
+	rom_selected(NULL);
     SavestateSelect* dlg = new SavestateSelect(this, m_Roms.at(ui->listWidget->currentRow()));
     if (dlg->exec() == QDialog::Accepted){
         int slot = dlg->Selected();
@@ -162,6 +163,9 @@ void MainWindow::rom_exec(int disc, int slot)
                 return;
             }
 
+            if (current_config.contains("-guncon"))
+                QProcess::execute("sudo", QStringList() << "chmod" << "666" << "/dev/input/event3");
+
             ui->pushButton->setEnabled(false);
             ui->pushButton_2->setEnabled(false);
             ui->pbnSstate->setEnabled(false);
@@ -188,6 +192,9 @@ void MainWindow::rom_exec(int disc, int slot)
 
 void MainWindow::process_finished(int exitCode)
 {
+    if (current_config.contains("-guncon"))
+        QProcess::execute("sudo", QStringList() << "chmod" << "660" << "/dev/input/event3");
+
     if (exitCode){
         QString error = myProcess->readAllStandardError();
         QMessageBox msg(this);
