@@ -10,7 +10,11 @@ MemoryCardSelect::MemoryCardSelect(QWidget *parent, QString selected) :
 {
     ui->setupUi(this);
     connect(ui->pbnOk, SIGNAL(clicked()), this, SLOT(accept()));
+#ifdef Q_WS_MAEMO_5
     connect(ui->listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(MemoryCardSelected(QListWidgetItem*)));
+#else
+    connect(ui->listWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(MemoryCardSelected(QListWidgetItem*)));
+#endif
 
     FillList();
     if (!selected.isEmpty()){
