@@ -21,6 +21,24 @@ options::options(QWidget *parent) :
     connect(ui->pbnMemoryCard2, SIGNAL(clicked()),this,SLOT(memory_card_2()));
     connect(ui->pbnConfigAccel, SIGNAL(clicked()), this, SLOT(config_accel()));
     connect(ui->radioButton, SIGNAL(toggled(bool)), this, SLOT(coreChanged(bool)));
+    connect(ui->chkCorners,SIGNAL(toggled(bool)),this,SLOT(corners_toggled(bool)));
+
+    QStringList actions = QStringList() << tr("No action") << tr("Save") << tr("Load")
+                                        << tr("Change slot (+1)") << tr("Change slot (-1)")
+                                        << tr("Quit");
+    foreach (QString action, actions){
+        ui->cmbTopLet->addItem(action);
+        ui->cmbTopRight->addItem(action);
+        ui->cmbBottomLeft->addItem(action);
+        ui->cmbBottomRight->addItem(action);
+    }
+
+    QStringList controllers = QStringList() << tr("Pad (SCPH-1080, SCPH-1150)") << tr("GunCon (SLPH-00034)");
+    foreach (QString controller, controllers){
+        ui->cmbControllerType->addItem(controller);
+    }
+    connect(ui->cmbControllerType, SIGNAL(currentIndexChanged(int)), this, SLOT(controllerChangedSlot(int)));
+
     load_cfg();
 
     m_Loop = NULL;
@@ -71,7 +89,7 @@ void options::load_cfg()
     configs << "accel" << "cdda" << "xa" << "rcnt" << "sio" << "spuirq" << "vsync" << "fsaa" << "pcsx-fullscreen";
     configs << "pcsx-fps" << "pcsx-cpu" << "pcsx-nofl" << "mcd1" << "mcd2" << "spu_reverb" << "spu_interpolation";
     configs << "region" << "analog" << "accel_sens" << "accel_y_def" << "accel_max" << "displayon" << "keys";
-    configs << "autosave" << "vibration";
+    configs << "autosave" << "vibration" << "corners" << "corneractions" << "guncon" << "gunnotrigger";
 
     ui->radioButton_2->setChecked(true);
     ui->comboBox_5->setCurrentIndex(0);
@@ -83,6 +101,12 @@ void options::load_cfg()
     ui->cmbInterpolation->setCurrentIndex(0);
     ui->cmbRegion->setCurrentIndex(0);
 
+    ui->chkCorners->setChecked(false);
+    ui->cmbTopLet->setCurrentIndex(0);
+    ui->cmbTopRight->setCurrentIndex(0);
+    ui->cmbBottomLeft->setCurrentIndex(0);
+    ui->cmbBottomRight->setCurrentIndex(0);
+
     if (ui->cmbKeysConfig->findText("Default") != -1)
         ui->cmbKeysConfig->setCurrentIndex(ui->cmbKeysConfig->findText("Default"));
     else
@@ -92,6 +116,8 @@ void options::load_cfg()
     ui->numYDef->setValue(500);
     ui->numMaxValue->setValue(500);
     ui->chkAutosave->setChecked(false);
+    ui->cmbControllerType->setCurrentIndex(0);
+    ui->chkGunNoTrigger->setChecked(false);
 
     if (QFile::exists(path)){
         QFile file(path);
@@ -234,6 +260,23 @@ void options::load_cfg()
                  case 37:
                       if (value=="1")ui->chkVibration->setChecked(true);else ui->chkVibration->setChecked(false);
                       break;
+                 case 38:
+                      if (value=="1")ui->chkCorners->setChecked(true);else ui->chkCorners->setChecked(false);
+                      break;
+                 case 39:
+                      if (value.length() >= 4){
+                          ui->cmbTopLet->setCurrentIndex(QString("%1").arg(value.at(0)).toInt());
+                          ui->cmbTopRight->setCurrentIndex(QString("%1").arg(value.at(1)).toInt());
+                          ui->cmbBottomRight->setCurrentIndex(QString("%1").arg(value.at(2)).toInt());
+                          ui->cmbBottomLeft->setCurrentIndex(QString("%1").arg(value.at(3)).toInt());
+                      }
+                      break;
+                 case 40:
+                      if (value=="1")ui->cmbControllerType->setCurrentIndex(1);
+                      break;
+                 case 41:
+                      if (value=="1")ui->chkGunNoTrigger->setChecked(true);else ui->chkGunNoTrigger->setChecked(false);
+                      break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -244,6 +287,8 @@ void options::load_cfg()
              // checking
              psx4m_hwa_block();
              accel_toggled(ui->checkBox_9->isChecked());
+             corners_toggled(ui->chkCorners->isChecked());
+             controllerChangedSlot(ui->cmbControllerType->currentIndex());
 
              if (!ui->comboBox_4->currentIndex()>-1)ui->comboBox_4->setCurrentIndex(0);
 
@@ -275,14 +320,27 @@ void options::createCfg(){
     {
         current_core="pcsx";
 
-        if (ui->chkVibration->isChecked())current_config<<"-vibration";
+        if (ui->chkCorners->isChecked()){
+            current_config<<"-corners";
+            current_config << QString("%1%2%3%4").arg(ui->cmbTopLet->currentIndex()).arg(ui->cmbTopRight->currentIndex())
+                                                 .arg(ui->cmbBottomRight->currentIndex()).arg(ui->cmbBottomLeft->currentIndex());
+        }
+
+        bool guncon = ui->cmbControllerType->currentIndex()==1;
+        if (guncon){
+            current_config<<"-guncon";
+            if (ui->chkGunNoTrigger->isChecked())current_config<<"-gunnotrigger";
+        }
+        else{
+            if (ui->chkVibration->isChecked())current_config<<"-vibration";
+            if (ui->chkAnalog->isChecked())current_config<<"-analog";
+            current_config<<"-sens"<<QString::number(ui->numSens->value());
+            current_config<<"-ydef"<<QString::number(ui->numYDef->value());
+            current_config<<"-max"<<QString::number(ui->numMaxValue->value());
+        }
+
         if (ui->chkAutosave->isChecked())current_config<<"-autosave";
         if (ui->chkDisplayOn->isChecked())current_config<<"-displayon";
-        if (ui->chkAnalog->isChecked())current_config<<"-analog";
-        current_config<<"-sens"<<QString::number(ui->numSens->value());
-        current_config<<"-ydef"<<QString::number(ui->numYDef->value());
-        current_config<<"-max"<<QString::number(ui->numMaxValue->value());
-
         if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
         if (ui->comboBox_5->currentText()=="oldgpu")current_config<<"-oldgpu";
         else if (ui->comboBox_5->currentText()=="gpu-gles")current_config<<"-gles";
@@ -386,7 +444,11 @@ void options::save_cfg(){
                    "displayon=%35\n" \
                    "keys=%36\n" \
                    "autosave=%37\n" \
-                   "vibration=%38\n")
+                   "vibration=%38\n" \
+                   "corners=%39\n" \
+                   "corneractions=%40\n" \
+                   "guncon=%41\n" \
+                   "gunnotrigger=%42\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -424,7 +486,12 @@ void options::save_cfg(){
             .arg(ui->chkDisplayOn->isChecked()?"1":"0")
             .arg(ui->cmbKeysConfig->currentText())
             .arg(ui->chkAutosave->isChecked()?"1":"0")
-            .arg(ui->chkVibration->isChecked()?"1":"0");
+            .arg(ui->chkVibration->isChecked()?"1":"0")
+            .arg(ui->chkCorners->isChecked()?"1":"0")
+            .arg(QString("%1%2%3%4").arg(ui->cmbTopLet->currentIndex()).arg(ui->cmbTopRight->currentIndex())
+                                    .arg(ui->cmbBottomRight->currentIndex()).arg(ui->cmbBottomLeft->currentIndex()))
+            .arg(ui->cmbControllerType->currentIndex() == 1?"1":"0")
+            .arg(ui->chkGunNoTrigger->isChecked()?"1":"0");
 
     QFile file(path);
     QFileInfo pathInfo(path);
@@ -595,3 +662,30 @@ bool options::isSupported(QString core, QString romFileName)
     }
     return false;
 }
+
+void options::corners_toggled(bool toggled)
+{
+    ui->cmbTopLet->setEnabled(toggled);
+    ui->cmbTopRight->setEnabled(toggled);
+    ui->cmbBottomLeft->setEnabled(toggled);
+    ui->cmbBottomRight->setEnabled(toggled);
+}
+
+void options::controllerChangedSlot(int index)
+{
+    bool enabled = index != 1;
+
+    ui->chkGunNoTrigger->setEnabled(!enabled);
+    ui->chkAnalog->setEnabled(enabled);
+    ui->chkCorners->setEnabled(enabled);
+    ui->chkVibration->setEnabled(enabled);
+    ui->checkBox_9->setEnabled(enabled);
+
+    if (enabled){
+        accel_toggled(ui->checkBox_9->isChecked());
+        corners_toggled(ui->chkCorners->isChecked());
+    }else{
+        accel_toggled(enabled);
+        corners_toggled(enabled);
+    }
+}
