@@ -31,6 +31,8 @@ public slots:
     void accel_toggled(bool toggled);
     void config_accel();
     void coreChanged(bool);
+    void corners_toggled(bool toggled);
+    void controllerChangedSlot(int index);
 
 protected:
     void hideEvent(QHideEvent *);
